@@ -162,10 +162,10 @@ async def configure_module_training(request):
     elif run_command == 'jupyterlab':
         flash.flash(
             request,
-            ("warning", 'Remember to set a Jupyter password.')
+            ("warning", 'Remember to set a Jupyter password (mandatory).')
         )
         inputs['run_command']['default'] = (
-            '/srv/.jupyter/run_jupyter.sh --allow-root'
+            '/srv/.deep-start/run_jupyter.sh --allow-root'
         )
         if hardware_configuration == 'gpu':
             inputs['run_command']['default'] = (
@@ -191,6 +191,7 @@ async def configure_module_training(request):
 
     inputs['docker_image']['default'] += ':{}'.format(docker_tag)
 
+    # Group tosca options
     grouped = {
         "docker": {},
         "jupyter": {},
@@ -214,6 +215,11 @@ async def configure_module_training(request):
         else:
             grouped["other"][k] = v
 
+    # Remove empty groups
+    for k, v in list(grouped.items()):
+        if not v:
+            del grouped[k]
+
     template_meta = {
         "inputs": inputs,
         "grouped": grouped,
